==> dhall-json-1.7.2-19-x86_64.pkg.tar.zst: usr/share/haskell/register/dhall-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dhall-json
version:              1.7.2
visibility:           public
id:                   dhall-json-1.7.2-QaRLsFcfAPDglzPVnxSyS
key:                  dhall-json-1.7.2-QaRLsFcfAPDglzPVnxSyS
license:              BSD-3-Clause
copyright:            2017 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             Convert between Dhall and JSON or YAML
description:
    Use this package if you want to convert between Dhall expressions and JSON
    or YAML. You can use this package as a library or an executable:

    * See the "Dhall.JSON" or "Dhall.JSONToDhall" modules if you want to use
    this package as a library

    * Use the @dhall-to-json@, @dhall-to-yaml@, or @json-to-dhall@ programs from
    this package if you want an executable

    The "Dhall.JSON" and "Dhall.JSONToDhall" modules also contains instructions
    for how to use this package

category:             Compiler
abi:                  1c49d4500a786971653867bc6e2ce023
exposed:              True
exposed-modules:
    Dhall.DhallToYaml.Main Dhall.JSON Dhall.JSON.Yaml Dhall.JSONToDhall

hidden-modules:       Dhall.JSON.Util
import-dirs:          /usr/lib/ghc-8.10.2/site-local/dhall-json-1.7.2
library-dirs:         /usr/lib/ghc-8.10.2/site-local/dhall-json-1.7.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-json
hs-libraries:         HSdhall-json-1.7.2-QaRLsFcfAPDglzPVnxSyS
depends:
    aeson-1.5.4.1-GV5FdxcUzlgLc5Y3bX6BKz
    aeson-pretty-0.8.8-DAUmU0YIALu3FzHLhqHdma
    aeson-yaml-1.1.0.0-9NiuYVQmTQm34wwb8pK4u9 base-4.14.1.0
    bytestring-0.10.10.0 containers-0.6.2.1
    dhall-1.35.0-L7bheCC6531IpYDd7IHLDE exceptions-0.10.4
    filepath-1.4.2.1 lens-family-core-2.1.0-8Brfqh2QzxlSD99dQOYhI
    optparse-applicative-0.15.1.0-EGSqvGNokMX25ehE0zny79
    prettyprinter-1.7.0-HyYfKbOG4vGHXB57VY2lAo
    scientific-0.3.6.2-9r3xAXriXhw1F5N3fuv0sB text-1.2.3.2
    unordered-containers-0.2.13.0-KkafibQ6xVADBmu5FlpAf0
    vector-0.12.1.2-3tvt8fo7Juj3zpRn38O867

haddock-interfaces:   /usr/share/doc/dhall-json/html/dhall-json.haddock
haddock-html:         /usr/share/doc/dhall-json/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> dhall-json-1.7.3-9-x86_64.pkg.tar.zst: usr/share/haskell/register/dhall-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dhall-json
version:              1.7.3
visibility:           public
id:                   dhall-json-1.7.3-ArhUQ8KosXs6ZufozkHG8r
key:                  dhall-json-1.7.3-ArhUQ8KosXs6ZufozkHG8r
license:              BSD-3-Clause
copyright:            2017 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             Convert between Dhall and JSON or YAML
description:
    Use this package if you want to convert between Dhall expressions and JSON
    or YAML. You can use this package as a library or an executable:

    * See the "Dhall.JSON" or "Dhall.JSONToDhall" modules if you want to use
    this package as a library

    * Use the @dhall-to-json@, @dhall-to-yaml@, or @json-to-dhall@ programs from
    this package if you want an executable

    The "Dhall.JSON" and "Dhall.JSONToDhall" modules also contains instructions
    for how to use this package

category:             Compiler
abi:                  4b12ee4a0c0627efdcc95666ae1fb3d5
exposed:              True
exposed-modules:
    Dhall.DhallToYaml.Main Dhall.JSON Dhall.JSON.Yaml Dhall.JSONToDhall

hidden-modules:       Dhall.JSON.Util
import-dirs:          /usr/lib/ghc-8.10.2/site-local/dhall-json-1.7.3
library-dirs:         /usr/lib/ghc-8.10.2/site-local/dhall-json-1.7.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-json
hs-libraries:         HSdhall-json-1.7.3-ArhUQ8KosXs6ZufozkHG8r
depends:
    aeson-1.5.4.1-A0L815KAfIF5MogEzEmc2
    aeson-pretty-0.8.8-21J6iSSunyPGLOXcoweNHX
    aeson-yaml-1.1.0.0-2Omw7y5bkD9HlnMByMYkjJ base-4.14.1.0
    bytestring-0.10.10.0 containers-0.6.2.1
    dhall-1.36.0-KWrIwv2MvcFJwWbhtwxQvn exceptions-0.10.4
    filepath-1.4.2.1 lens-family-core-2.1.0-8Brfqh2QzxlSD99dQOYhI
    optparse-applicative-0.16.0.0-GaU2pquuIv7LM0Blpt3Fs8
    prettyprinter-1.7.0-F78MabeDMlDJBljAjR2kxa
    scientific-0.3.6.2-A6GpmAfE5b3I5gMkXmBkHk text-1.2.3.2
    unordered-containers-0.2.13.0-KjldV6HJtaDB1Zm2KKQlBR
    vector-0.12.1.2-2m8MnQowu1eAEJcsrPdtQL

haddock-interfaces:   /usr/share/doc/dhall-json/html/dhall-json.haddock
haddock-html:         /usr/share/doc/dhall-json/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
